package com.upay.sdk.transferaccount.v_3;

import com.alibaba.fastjson.JSONObject;
import com.upay.sdk.exception.HmacVerifyException;
import com.upay.sdk.exception.RequestException;
import com.upay.sdk.exception.ResponseException;
import com.upay.sdk.exception.UnknownException;
import com.upay.sdk.executer.ResultListenerAdpater;
import com.upay.sdk.transferaccount.builder.OrderBuilder;
import com.upay.sdk.transferaccount.executer.TransferAccountOrderExecuter;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.IOException;
import java.io.PrintWriter;

public class OrderServlet extends HttpServlet {

    static final Logger LOGGER = LoggerFactory.getLogger(OrderServlet.class);

    @Override
    protected void doGet(HttpServletRequest req, HttpServletResponse resp) throws ServletException, IOException {
        doPost(req, resp);
    }

    @Override
    protected void doPost(HttpServletRequest req, final HttpServletResponse resp) throws ServletException, IOException {

        req.setCharacterEncoding("UTF-8");
        String merchantId = req.getParameter("merchantId");
        String partnerId = req.getParameter("partnerId");
        String requestId = req.getParameter("requestId");
        String receiverId = req.getParameter("receiverId");
        String receiverType = req.getParameter("receiverType");
        String amount = req.getParameter("amount");
        String currency = req.getParameter("currency");
        String remark = req.getParameter("remark");
        String notifyUrl = req.getParameter("notifyUrl");
        String deputeMark = req.getParameter("deputeMark");

        OrderBuilder builder = new OrderBuilder(merchantId);
        builder.setPartnerId(partnerId).setRequestId(requestId).setReceiverId(receiverId).setReceiverType(receiverType)
                .setAmount(amount).setCurrency(currency).setRemark(remark).setNotifyUrl(notifyUrl);
        builder.setDeputeMark(deputeMark);

        final PrintWriter out = resp.getWriter();

        TransferAccountOrderExecuter executer = new TransferAccountOrderExecuter();
        try {
            executer.bothOrder(builder, new ResultListenerAdpater() {
                /**
                 * 提交成功，不代表支付成功
                 */
                @Override
                public void success(JSONObject jsonObject) {
                    out.println("提交成功</br>");
                    out.println(jsonObject);
                }

                @Override
                public void redirect(JSONObject jsonObject, String redirectUrl) throws IOException {
                    resp.sendRedirect(redirectUrl);
                    LOGGER.info("redirectUrl:[" + redirectUrl + "]");
                }
            });
        } catch (ResponseException e) {
            out.println("响应异常</br>");
            out.println(e.toString());
            LOGGER.error("transfer order error:", e);
        } catch (HmacVerifyException e) {
            out.println("签名验证异常</br>");
            out.println(e.toString());
            LOGGER.error("transfer order error:", e);
        } catch (RequestException e) {
            out.println("请求异常</br>");
            out.println(e.toString());
            LOGGER.error("transfer order error:", e);
        } catch (UnknownException e) {
            out.println("未知异常</br>");
            out.println(e.toString());
            LOGGER.error("transfer order error:", e);
        }
    }
}
